@@ -2,7 +2,6 @@
 import factory
 import core
 import ext
-import rest
 import utils
 
 from .client import Client, JSONClient
@@ -17,5 +16,12 @@ from .core import (
 	auth
 )
 
-__version__ = '0.1.5'
-__author__ = 'Derrick Gilland <dgilland@gmail.com>'
+from .__meta__ import (
+    __title__,
+    __summary__,
+    __url__,
+    __version__,
+    __author__,
+    __email__,
+    __license__
+)
